==> webmeter-core-1.0.8-3-sources.jar: com/aote/webmeter/tools/iot/TelecomApi.java <==
package com.aote.webmeter.tools.iot;

import com.aote.webmeter.tools.WebMeterInfo;

/**
 * 物联网表服务 电信IOT平台接口地址
 * @author Mr.river
 */
public class TelecomApi {

    private static final String BASE_URL = "https://device.api.ct10649.com:8743";
    private static final String AEP_URL = "http://ag-api.ctwing.cn";
    private static final String AUTH_URL = "/iocm/app/sec/v1.1.0/login";
    private static final String REFRESH_AUTH_URL = "/iocm/app/sec/v1.1.0/refreshToken";
    private static final String DEVICE_CREATE_URL = "/iocm/app/reg/v1.1.0/deviceCredentials";
    private static final String DEVICE_UPDATE_URL = "/iocm/app/dm/v1.4.0/devices";
    private static final String SEND_INSTRUCT_URL = "/iocm/app/cmd/v1.4.0/deviceCommands";
    private static final String SUBSCRIPTIONS_URL = "/iocm/app/sub/v1.2.0/subscriptions";


    public static String getAuthUrl() {
        return getUrl() + AUTH_URL;
    }

    public static String getRefreshAuthUrl() {
        return getUrl() + REFRESH_AUTH_URL;
    }

    public static String getDeviceCreateUrl() {
        return getUrl() + DEVICE_CREATE_URL;
    }

    public static String getDeviceUpdateUrl() {
        return getUrl() + DEVICE_UPDATE_URL;
    }

    public static String getSendInstructUrl() {
        return getUrl() + SEND_INSTRUCT_URL;
    }

    public static String getSubscriptionsUrl() {
        return getUrl() + SUBSCRIPTIONS_URL;
    }

    private static String getUrl(){
        if(IotCommonTools.getIsAep() == 0){
            return BASE_URL;
        } else if(IotCommonTools.getIsAep() == 1){
            return AEP_URL;
        } else {
            return WebMeterInfo.getString("telecom2Url");
        }
    }
}

==> webmeter-core-1.0.20-rc3-sources.jar: com/aote/webmeter/tools/iot/TelecomApi.java <==
package com.aote.webmeter.tools.iot;

import com.aote.webmeter.enums.WebmeterPropertiesIOTEnum;
import com.aote.webmeter.tools.WebMeterInfo;

/**
 * 物联网表服务 电信IOT平台接口地址
 * @author Mr.river
 */
public class TelecomApi {

    private static final String BASE_URL = "https://device.api.ct10649.com:8743";
    private static final String AEP_URL = "http://ag-api.ctwing.cn";
    private static final String AUTH_URL = "/iocm/app/sec/v1.1.0/login";
    private static final String REFRESH_AUTH_URL = "/iocm/app/sec/v1.1.0/refreshToken";
    private static final String DEVICE_CREATE_URL = "/iocm/app/reg/v1.1.0/deviceCredentials";
    private static final String DEVICE_UPDATE_URL = "/iocm/app/dm/v1.4.0/devices";
    private static final String SEND_INSTRUCT_URL = "/iocm/app/cmd/v1.4.0/deviceCommands";
    private static final String SUBSCRIPTIONS_URL = "/iocm/app/sub/v1.2.0/subscriptions";


    public static String getAuthUrl() {
        return getUrl() + AUTH_URL;
    }

    public static String getRefreshAuthUrl() {
        return getUrl() + REFRESH_AUTH_URL;
    }

    public static String getDeviceCreateUrl() {
        return getUrl() + DEVICE_CREATE_URL;
    }

    public static String getDeviceUpdateUrl() {
        return getUrl() + DEVICE_UPDATE_URL;
    }

    public static String getSendInstructUrl() {
        return getUrl() + SEND_INSTRUCT_URL;
    }

    public static String getSubscriptionsUrl() {
        return getUrl() + SUBSCRIPTIONS_URL;
    }

    private static String getUrl(){
        if(IotCommonTools.getIsAep() == 0){
            return BASE_URL;
        } else if(IotCommonTools.getIsAep() == 1){
            if(WebMeterInfo.has(WebmeterPropertiesIOTEnum.AEP_API_URL)){
                return WebMeterInfo.getString(WebmeterPropertiesIOTEnum.AEP_API_URL);
            }
            return AEP_URL;
        } else {
            return WebMeterInfo.getString(WebmeterPropertiesIOTEnum.OC2_API_URL);
        }
    }
}
